@@ -46,7 +46,7 @@ import numpy as np
 from scipy.special import hyp0f1
 
 from orix.quaternion import Quaternion
-from orix.vector import Vector3d
+from orix.vector import AxAngle, Vector3d
 from orix.scalar import Scalar
 
 # Used to round values below 1e-16 to zero
@@ -62,11 +62,11 @@ class Rotation(Quaternion):
     - Inversion.
     - Multiplication with other rotations and vectors.
 
-    Rotations inherit all methods from :class:`Quaternion` although behaviour is
-    different in some cases.
+    Rotations inherit all methods from :class:`Quaternion` although
+    behaviour is different in some cases.
 
-    Rotations can be converted to other parametrizations, notably the neo-Euler
-    representations. See :class:`NeoEuler`.
+    Rotations can be converted to other parametrizations, notably the
+    neo-Euler representations. See :class:`NeoEuler`.
     """
 
     def __init__(self, data):
@@ -122,12 +122,11 @@ class Rotation(Quaternion):
         """Returns a new object containing only this object's unique
         entries.
 
-        Two rotations are not unique if:
+        Two rotations are not unique if they have the same propriety
+        AND:
 
-            - they have the same propriety AND
-                - they have the same numerical value OR
-                - the numerical value of one is the negative of the
-                  other
+        - they have the same numerical value OR
+        - the numerical value of one is the negative of the other
 
         Parameters
         ----------
@@ -210,9 +209,19 @@ class Rotation(Quaternion):
         angles = Scalar(np.nan_to_num(np.arccos(2 * dp ** 2 - 1)))
         return angles
 
-    def outer(self, other, **kwargs):
-        """Compute the outer product of this rotation and the other object."""
-        r = super().outer(other, **kwargs)
+    def outer(self, other):
+        """Compute the outer product of this rotation and the other
+        rotation or vector.
+
+        Parameters
+        ----------
+        other : Rotation or Vector3d
+
+        Returns
+        -------
+        Rotation or Vector3d
+        """
+        r = super().outer(other)
         if isinstance(r, Rotation):
             r.improper = np.logical_xor.outer(self.improper, other.improper)
         if isinstance(r, Vector3d):
@@ -262,8 +271,39 @@ class Rotation(Quaternion):
         r = cls(np.stack([a, b, c, d], axis=-1))
         return r
 
+    @classmethod
+    def from_axes_angles(cls, axes, angles):
+        """Creates rotation(s) from axis-angle pair(s).
+
+        Parameters
+        ----------
+        axes : Vector3d or array_like
+            The axis of rotation.
+        angles : array_like
+            The angle of rotation, in radians.
+
+        Returns
+        -------
+        Rotation
+
+        Examples
+        --------
+        >>> import numpy as np
+        >>> from orix.quaternion import Rotation
+        >>> rot = Rotation.from_axes_angles((0, 0, -1), np.pi / 2)
+        >>> rot
+        Rotation (1,)
+        [[ 0.7071  0.      0.     -0.7071]]
+
+        See Also
+        --------
+        from_neo_euler
+        """
+        axangle = AxAngle.from_axes_angles(axes, angles)
+        return cls.from_neo_euler(axangle)
+
     def to_euler(self, convention="bunge"):
-        """Rotations as Euler angles.
+        r"""Rotations as Euler angles :cite:`rowenhorst2015consistent`.
 
         Parameters
         ----------
@@ -273,7 +313,9 @@ class Rotation(Quaternion):
         Returns
         -------
         ndarray
-            Array of Euler angles in radians.
+            Array of Euler angles in radians, in the ranges
+            :math:`\phi_1 \in [0, 2\pi]`, :math:`\Phi \in [0, \pi]`, and
+            :math:`\phi_1 \in [0, 2\pi]`.
         """
         # TODO: other conventions
         if convention != "bunge":
@@ -284,41 +326,54 @@ class Rotation(Quaternion):
         n = self.data.shape[:-1]
         e = np.zeros(n + (3,))
 
-        # move into pure numpy
         a, b, c, d = self.a.data, self.b.data, self.c.data, self.d.data
 
-        q_zero_three = a ** 2 + d ** 2
-        q_one_two = b ** 2 + c ** 2
-        chi = np.sqrt(q_zero_three * q_one_two)
+        q03 = a ** 2 + d ** 2
+        q12 = b ** 2 + c ** 2
+        chi = np.sqrt(q03 * q12)
 
         # P = 1
 
-        if np.sum(q_one_two == 0) > 0:  # checks that this occurs somewhere in data
+        q12_is_zero = q12 == 0
+        if np.sum(q12_is_zero) > 0:
             alpha = np.arctan2(-2 * a * d, a ** 2 - d ** 2)
-            cond = [q_one_two == 0]
-            e[..., 0] = np.where(cond, alpha, e[..., 0])
-            e[..., 1] = np.where(cond, 0, e[..., 1])
-            e[..., 2] = np.where(cond, 0, e[..., 2])
+            e[..., 0] = np.where(q12_is_zero, alpha, e[..., 0])
+            e[..., 1] = np.where(q12_is_zero, 0, e[..., 1])
+            e[..., 2] = np.where(q12_is_zero, 0, e[..., 2])
 
-        if np.sum(q_zero_three == 0) > 0:
+        q03_is_zero = q03 == 0
+        if np.sum(q03_is_zero) > 0:
             alpha = np.arctan2(2 * b * c, b ** 2 - c ** 2)
-            cond = [q_zero_three == 0]
-            e[..., 0] = np.where(cond, alpha, e[..., 0])
-            e[..., 1] = np.where(cond, np.pi, e[..., 1])
-            e[..., 2] = np.where(cond, 0, e[..., 2])
+            e[..., 0] = np.where(q03_is_zero, alpha, e[..., 0])
+            e[..., 1] = np.where(q03_is_zero, np.pi, e[..., 1])
+            e[..., 2] = np.where(q03_is_zero, 0, e[..., 2])
 
         if np.sum(chi != 0) > 0:
+            not_zero = ~np.isclose(chi, 0)
             alpha = np.arctan2(
-                np.divide(b * d - a * c, chi), np.divide(-a * b - c * d, chi)
+                np.divide(
+                    b * d - a * c, chi, where=not_zero, out=np.full_like(chi, np.inf)
+                ),
+                np.divide(
+                    -a * b - c * d, chi, where=not_zero, out=np.full_like(chi, np.inf)
+                ),
             )
-            beta = np.arctan2(2 * chi, q_zero_three - q_one_two)
+            beta = np.arctan2(2 * chi, q03 - q12)
             gamma = np.arctan2(
-                np.divide(a * c + b * d, chi), np.divide(c * d - a * b, chi)
+                np.divide(
+                    a * c + b * d, chi, where=not_zero, out=np.full_like(chi, np.inf)
+                ),
+                np.divide(
+                    c * d - a * b, chi, where=not_zero, out=np.full_like(chi, np.inf)
+                ),
             )
+            e[..., 0] = np.where(not_zero, alpha, e[..., 0])
+            e[..., 1] = np.where(not_zero, beta, e[..., 1])
+            e[..., 2] = np.where(not_zero, gamma, e[..., 2])
 
-            e[..., 0] = np.where(chi != 0, alpha, e[..., 0])
-            e[..., 1] = np.where(chi != 0, beta, e[..., 1])
-            e[..., 2] = np.where(chi != 0, gamma, e[..., 2])
+        # Reduce Euler angles to definition range
+        e[np.abs(e) < _FLOAT_EPS] = 0
+        e = np.where(e < 0, np.mod(e + 2 * np.pi, (2 * np.pi, np.pi, 2 * np.pi)), e)
 
         return e
 
@@ -348,14 +403,6 @@ class Rotation(Quaternion):
 
         convention = convention.lower()
 
-        if convention == "krakow_hielscher":
-            # To be applied to the data found at:
-            # https://www.repository.cam.ac.uk/handle/1810/263510
-            warnings.warn(
-                "This method is deprecated and will be removed in v0.8 use 'MTEX' instead"
-            )
-            convention = "mtex"
-
         if convention not in conventions:
             raise ValueError(
                 f"The chosen convention is not one of the allowed options {conventions}"
@@ -399,7 +446,7 @@ class Rotation(Quaternion):
             data = ~data
 
         rot = cls(data.data)
-        rot.improper = np.zeros((n))
+        rot.improper = np.zeros(n)
         return rot
 
     def to_matrix(self):
