@@ -100,7 +100,7 @@ class TestAngReader:
                 (0.1, 0.1),
                 np.zeros(5 * 3, dtype=int),
                 np.array(
-                    [[1.59942, 2.37748, -1.74690], [1.59331, 2.37417, -1.74899]]
+                    [[1.59942, 2.37748, 4.53419], [1.59331, 2.37417, 4.53628]]
                 ),  # rotations as rows of Euler angle triplets
             ),
             (
@@ -117,7 +117,7 @@ class TestAngReader:
                 (1.5, 1.5),
                 np.zeros(8 * 4, dtype=int),
                 np.array(
-                    [[-0.12113, 2.34188, 1.31702], [-0.47211, 0.79936, -1.80973]]
+                    [[5.81107, 2.34188, 4.47345], [6.16205, 0.79936, 1.31702]]
                 ),  # rotations as rows of Euler angle triplets
             ),
         ],
@@ -222,7 +222,7 @@ class TestAngReader:
                 (10, 10),
                 np.ones(11 * 13, dtype=int),
                 np.array(
-                    [[1.621760, 2.368935, -1.723861], [1.604481, 2.367539, -1.741315]]
+                    [[1.621760, 2.368935, 4.559324], [1.604481, 2.367539, 4.541870]]
                 ),
             ),
         ],
@@ -314,7 +314,7 @@ class TestAngReader:
                         )
                     ),  # phase_id
                     np.array(
-                        [[1.62176, 2.36894, -1.72386], [1.60448, 2.36754, -1.72386]]
+                        [[1.62176, 2.36894, 1.72386], [1.60448, 2.36754, 1.72386]]
                     ),
                 ),
                 (3, 6),
@@ -325,7 +325,7 @@ class TestAngReader:
                         np.ones(int(np.floor((3 * 6) / 2))) * 2,
                     )
                 ),
-                np.array([[1.62176, 2.36894, -1.72386], [1.60448, 2.36754, -1.72386]]),
+                np.array([[1.62176, 2.36894, 1.72386], [1.60448, 2.36754, 1.72386]]),
             ),
         ],
         indirect=["angfile_emsoft"],
