@@ -16,14 +16,15 @@
 # You should have received a copy of the GNU General Public License
 # along with orix.  If not, see <http://www.gnu.org/licenses/>.
 
-from diffpy.structure.spacegroups import sg225
 from math import cos, sin, tan, pi
+
+from diffpy.structure.spacegroups import sg225
 import numpy as np
 import pytest
 
-from orix.quaternion import Quaternion
-from orix.quaternion.rotation import Rotation
-from orix.vector import Vector3d
+from orix.quaternion import Quaternion, Rotation
+from orix.vector import AxAngle, Vector3d
+
 
 rotations = [
     (0.707, 0.0, 0.0, 0.707),
@@ -222,12 +223,12 @@ class TestToFromEuler:
         e2 = r.to_euler()
         assert np.allclose(e, e2.data)
 
+    def test_mtex(self, e):
+        _ = Rotation.from_euler(e, convention="mtex")
+
     def test_direction_kwarg(self, e):
         _ = Rotation.from_euler(e, direction="lab2crystal")
 
-    def test_Krakow_Hielscher(self, e):
-        _ = Rotation.from_euler(e, convention="Krakow_Hielscher")
-
     def test_direction_kwarg_dumb(self, e):
         with pytest.raises(ValueError, match="The chosen direction is not one of "):
             _ = Rotation.from_euler(e, direction="dumb_direction")
@@ -527,3 +528,20 @@ class TestFromToMatrix:
         """
         r = Rotation.from_matrix([i.R for i in sg225.symop_list])
         assert not np.isnan(r.data).any()
+
+
+class TestFromAxesAngles:
+    """These tests address Rotation.from_axes_angles()."""
+
+    def test_from_axes_angles(self, rotations):
+        axangle = AxAngle.from_rotation(rotations)
+        rotations2 = Rotation.from_neo_euler(axangle)
+        rotations3 = Rotation.from_axes_angles(axangle.axis.data, axangle.angle.data)
+        assert np.allclose(rotations2.data, rotations3.data)
+
+
+def test_to_euler_not_warning():
+    rot = Rotation(((0, 1, 0, 0), (1, 0, 0, 0), (1, 1, 0, 0)))
+    with pytest.warns(None) as record:
+        _ = rot.to_euler()
+    assert len(record) == 0
