@@ -21,11 +21,9 @@ from matplotlib_scalebar.scalebar import ScaleBar
 import numpy as np
 import pytest
 
-from orix.crystal_map import CrystalMap
-from orix.crystal_map.phase_list import Phase, PhaseList
+from orix.crystal_map import CrystalMap, Phase, PhaseList
 from orix.plot import CrystalMapPlot
-from orix.quaternion.orientation import Orientation
-from orix.quaternion.rotation import Rotation
+from orix.quaternion import Orientation, Rotation
 from orix.quaternion.symmetry import C2, C3, C4, O
 
 
@@ -501,18 +499,19 @@ class TestCrystalMapOrientations:
         xmap.phases = PhaseList(Phase("a", point_group=point_group))
 
         o = xmap.orientations
+        o = o.map_into_symmetry_reduced_zone()
 
-        assert np.allclose(
-            o.data, Orientation(r).set_symmetry(point_group).data, atol=1e-3
-        )
+        o1 = Orientation(r)
+        o1.symmetry = point_group
+        o1 = o1.map_into_symmetry_reduced_zone()
+
+        assert np.allclose(o.data, o1.data, atol=1e-3)
         assert np.allclose(o.data, expected_orientation, atol=1e-3)
 
     def test_orientations_none_symmetry_raises(self, crystal_map_input):
         xmap = CrystalMap(**crystal_map_input)
-
-        assert xmap.phases.point_groups == [None]
-
-        with pytest.raises(TypeError, match="'NoneType' object is not iterable"):
+        assert xmap.phases[:].point_group is None
+        with pytest.raises(TypeError, match="Value must be an instance of"):
             _ = xmap.orientations
 
     def test_orientations_multiple_phases_raises(self, crystal_map, phase_list):
@@ -679,11 +678,9 @@ class TestCrystalMapGetMapData:
         for i, phase in xmap.phases_in_data:
             phase_mask = xmap._phase_id == i
             phase_mask_in_data = xmap.phase_id == i
-            array[phase_mask] = (
-                Orientation(rotations[phase_mask_in_data])
-                .set_symmetry(phase.point_group)
-                .to_euler()
-            )
+            oi = Orientation(rotations[phase_mask_in_data])
+            oi.symmetry = phase.point_group
+            array[phase_mask] = oi.to_euler()
 
         assert np.allclose(o, array.reshape(o.shape), atol=1e-3)
 
@@ -757,6 +754,20 @@ class TestCrystalMapGetMapData:
         assert not xmap.is_in_data.all()
         assert xmap.get_map_data(prop_name, fill_value=None).dtype == float
 
+    def test_get_map_data(self, crystal_map):
+        # Test decimals paramter
+        crystal_map.prop["iq"] = np.random.random(crystal_map.size)
+        iq1 = crystal_map.get_map_data("iq").flatten()
+        assert np.allclose(iq1, crystal_map.iq)
+        iq2 = crystal_map.get_map_data("iq", decimals=3).flatten()
+        assert not np.allclose(iq2, crystal_map.iq)
+        assert np.allclose(iq2, crystal_map.iq, atol=1e-3)
+
+        # Test https://github.com/pyxem/orix/issues/220
+        xmap2 = CrystalMap.empty((3,))
+        x = xmap2.get_map_data("x")
+        x2 = xmap2.get_map_data(xmap2.x)
+
 
 class TestCrystalMapRepresentation:
     def test_representation(self, crystal_map, phase_list):
