@@ -27,15 +27,17 @@ of a spherical region.
 
 # Must be imported first
 from orix.vector.vector3d import check_vector, Vector3d
+from orix.vector.spherical_region import SphericalRegion
 
+from orix.vector.fundamental_sector import FundamentalSector
 from orix.vector.miller import Miller
 from orix.vector.neo_euler import AxAngle, Homochoric, NeoEuler, Rodrigues
-from orix.vector.spherical_region import SphericalRegion
 
 # Lists what will be imported when calling "from orix.vector import *"
 __all__ = [
-    "check_vector",
     "AxAngle",
+    "check_vector",
+    "FundamentalSector",
     "Homochoric",
     "Miller",
     "NeoEuler",
